summaryrefslogtreecommitdiffstats
path: root/kdgantt/KDGanttSemiSizingControl.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kdgantt/KDGanttSemiSizingControl.cpp')
-rw-r--r--kdgantt/KDGanttSemiSizingControl.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/kdgantt/KDGanttSemiSizingControl.cpp b/kdgantt/KDGanttSemiSizingControl.cpp
index 08c1a004..bfaa161d 100644
--- a/kdgantt/KDGanttSemiSizingControl.cpp
+++ b/kdgantt/KDGanttSemiSizingControl.cpp
@@ -57,15 +57,15 @@
orientation and the control arrow button on top of the controlled
widget.
- \param tqparent the tqparent widget. This parameter is passed to the
+ \param parent the parent widget. This parameter is passed to the
base class.
\param name the internal widget name. This parameter is passed to
the base class.
*/
-KDGanttSemiSizingControl::KDGanttSemiSizingControl( TQWidget* tqparent,
+KDGanttSemiSizingControl::KDGanttSemiSizingControl( TQWidget* parent,
const char* name ) :
- KDGanttSizingControl( tqparent, name ), _orient( Qt::Horizontal ),
+ KDGanttSizingControl( parent, name ), _orient( Qt::Horizontal ),
_arrowPos( Before ), _minimizedWidget(0), _maximizedWidget(0)
{
init();
@@ -78,16 +78,16 @@ KDGanttSemiSizingControl::KDGanttSemiSizingControl( TQWidget* tqparent,
the controlled widget (depending on the orientation).
\param orientation the orientation of the splitter
- \param tqparent the tqparent widget. This parameter is passed to the
+ \param parent the parent widget. This parameter is passed to the
base class.
\param name the internal widget name. This parameter is passed to
the base class.
*/
KDGanttSemiSizingControl::KDGanttSemiSizingControl( Qt::Orientation orientation,
- TQWidget* tqparent,
+ TQWidget* parent,
const char* name ) :
- KDGanttSizingControl( tqparent, name ), _orient( orientation ),
+ KDGanttSizingControl( parent, name ), _orient( orientation ),
_arrowPos( Before ), _minimizedWidget(0), _maximizedWidget(0)
{
init();
@@ -101,7 +101,7 @@ KDGanttSemiSizingControl::KDGanttSemiSizingControl( Qt::Orientation orientation,
\param arrowPosition specifies whether the control arrow button
should appear before or after the controlled widget
\param orientation the orientation of the splitter
- \param tqparent the tqparent widget. This parameter is passed to the
+ \param parent the parent widget. This parameter is passed to the
base class.
\param name the internal widget name. This parameter is passed to
the base class.
@@ -109,9 +109,9 @@ KDGanttSemiSizingControl::KDGanttSemiSizingControl( Qt::Orientation orientation,
KDGanttSemiSizingControl::KDGanttSemiSizingControl( ArrowPosition arrowPosition,
Qt::Orientation orientation,
- TQWidget* tqparent,
+ TQWidget* parent,
const char* name ) :
- KDGanttSizingControl( tqparent, name ), _orient( orientation ),
+ KDGanttSizingControl( parent, name ), _orient( orientation ),
_arrowPos( arrowPosition ), _minimizedWidget(0), _maximizedWidget(0)
{
init();
@@ -313,7 +313,7 @@ void KDGanttSemiSizingControl::setup()
************************************************** */
// hack for the usage in KDGantt as pop-up legend widget
// for this purpose,
// the _maximizedWidget must be a child of the tqparent of this widget
if ( isMinimized() ) {
widget = _minimizedWidget;
@@ -313,7 +313,7 @@ void KDGanttSemiSizingControl::setup()
// hack for the usage in KDGantt as pop-up legend widget
// for this purpose,
- // the _maximizedWidget must be a child of the tqparent of this widget
+ // the _maximizedWidget must be a child of the parent of this widget
if ( isMinimized() ) {
widget = _minimizedWidget;